[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- ivy: Ivy is a lightweight software bus for quick-prototyping protocols. It allows applications to broadcast information through text messages, with a subscription mechanism based on regular expressions.
  - ivy.ivy: The following code is a typical example of use:
  - ivy.std_api: Implements the standard Ivy API.